# T7 RNA polymerase-based gene expression from a transcriptionally silent rDNA spacer in the endosymbiont-harboring trypanosomatid *Angomonas deanei*

This ARC [Annoteted Research Context](https://arc-rdm.org/) contains the original data of the Kröninger et al. publication.

## Original Publication

Publication
doi

## Table of Contents

1. [Abstract](## Abstract)
2. [Studies](## Studies) 
3. [Assays](## Assays)
4. [Licence](## License)



## Abstract

Eukaryotic life has been shaped fundamentally by the integration of bacterial endosymbionts. The trypanosomatid *Angomonas deanei* that contains a beta-proteobacterial endosymbiont, represents an emerging model to elucidate initial steps in symbiont integration. Although the repertoire of genetic tools for *A. deanei* is growing, no conditional gene expression system is available yet, which would be key for the functional characterization of essential or expression of toxic proteins. Development of a conditional expression system based on endogenous RNA polymerase II (POLII) is hampered by the absence of information on transcription signals in *A. deanei* as well as the unusual genetic system used in the Trypanosomatidae that relies on read-through transcription. This mode of transcription can result in polar effects when manipulating expression of genes in their endogenous loci. Finally, only few resistance markers are available for *A. deanei* yet, restricting the number of genetic modifications that can be introduced into one strain. To increase the range of possible genetic manipulations in *A. deanei*, and in particular, build the base for a conditional expression system that does not interfere with the endogenous gene expression machinery, here we (i) implemented two new drug resistance markers, (ii) identified the spacer upstream of the rDNA array on chromosome 13 as transcriptionally silent genomic locus, and (iii) used this locus for engineering an ectopic expression system that depends on the T7 RNA polymerase expressed from the delta-amastin locus. We show that transgene expression in this system is independent of the activity of endogenous RNA polymerases, reaches expression levels similar to the previously described POLII-dependent expression from the gamma-amastin locus, and can be applied for studying endosymbiosis. In sum, the new tools expand the possibilities for genetic manipulations of *A. deanei* and provide a solid base for the development of an ectopic conditional expression system.

## Studies

The Studies (S) are named after the names of the chapters in the publication.
* S1_Identification of potentially silent loci
* S2_Heterologous expression of the T7RNAP
* S3_Implementation of new antibiotic resistance cassettes
* S4_T7RNAP-driven expression from the rDNA spacer
* S5_Analysis of gene expression strength

## Assays

The [Assays] folder contains the results of the individual experiments. The raw and processed data are stored in the `dataset` folder of the assay and the corresponding protocols are in the `protocol` folder. 

### Chapter 1: Identification of potentially silent loci
* S1_1_rDNA spacers on different chromosomes // **Fig. 1**

### Chapter 2: Heterologous expression of the T7RNAP
* S2_1_Genomic map of Adea319 // **Fig. 2A**
* S2_2_Verification of genomic integration by PCR // **Fig. 2B**
* S2_3_Verification of T7RNAP production by Western Blot // **Fig. 2C**

### Chapter 3: Implementation of new antibiotic resistance cassettes
* S3_1_Growth curve of WT and Adea373 on blast // **Fig. 3A**
* S3_2_Growth curve of WT and Adea384 on nours // **Fig. 3B**

### Chapter 4: T7RNAP-driven expression from the rDNA spacer
* S4_1_Genomic map of Adea400 // **Fig. 4A**
* S4_2_Verification of insertion by PCR I // **Fig. 4B**
* S4_3_Verification of insertion by PCR II // **Fig. 4C**
* S4_4_Verification of insertion by Southern Blot // **Fig. 4D**
* S4_5_Growth curves of Adea319 and Adea400 // **Fig. 4E**
* S4_6_Knock-out strategy for T7RNAP // **Fig. 4F**
* S4_7_Verification of knock-out by PCR // **Fig. 4G**
* S4_8_Growth curves of WT, Adea373 and Adea442 // **Fig. 4H**

### Chapter 5: Analysis of gene expression strength
* S5_1_Genomic map of Adea456 // **Fig. 5A**
* S5_2_Verification of insertion by Southern Blot // **Fig. 5B**
* S5_3_Growth curves of WT and Adea456 // **Fig. 5C**
* S5_4_Epifluorescence microscopy of Adea126 and Adea456 // **Fig. 5D**
* S5_5_Quantification of fluorescent cells // **Fig. 5E**
* S5_6_In gel fluorescence assay of Adea126 and Adea456 // **Fig. 5F (top)**
=======
# T7 RNA polymerase-based gene expression from a transcriptionally silent rDNA spacer in the endosymbiont-harboring trypanosomatid *Angomonas deanei*

This ARC [Annoteted Research Context](https://arc-rdm.org/) contains the original data of the Kröninger et al. publication.

## Original Publication

Publication
doi

## Table of Contents

1. [Abstract](## Abstract)
2. [Studies](## Studies) 
3. [Assays](## Assays)
4. [Licence](## License)



## Abstract

Eukaryotic life has been shaped fundamentally by the integration of bacterial endosymbionts. The trypanosomatid *Angomonas deanei* that contains a beta-proteobacterial endosymbiont, represents an emerging model to elucidate initial steps in symbiont integration. Although the repertoire of genetic tools for *A. deanei* is growing, no conditional gene expression system is available yet, which would be key for the functional characterization of essential or expression of toxic proteins. Development of a conditional expression system based on endogenous RNA polymerase II (POLII) is hampered by the absence of information on transcription signals in *A. deanei* as well as the unusual genetic system used in the Trypanosomatidae that relies on read-through transcription. This mode of transcription can result in polar effects when manipulating expression of genes in their endogenous loci. Finally, only few resistance markers are available for *A. deanei* yet, restricting the number of genetic modifications that can be introduced into one strain. To increase the range of possible genetic manipulations in *A. deanei*, and in particular, build the base for a conditional expression system that does not interfere with the endogenous gene expression machinery, here we (i) implemented two new drug resistance markers, (ii) identified the spacer upstream of the rDNA array on chromosome 13 as transcriptionally silent genomic locus, and (iii) used this locus for engineering an ectopic expression system that depends on the T7 RNA polymerase expressed from the delta-amastin locus. We show that transgene expression in this system is independent of the activity of endogenous RNA polymerases, reaches expression levels similar to the previously described POLII-dependent expression from the gamma-amastin locus, and can be applied for studying endosymbiosis. In sum, the new tools expand the possibilities for genetic manipulations of *A. deanei* and provide a solid base for the development of an ectopic conditional expression system.

## Studies

The Studies (S) are named after the names of the chapters in the publication.
* S1_Identification of potentially silent loci
* S2_Heterologous expression of the T7RNAP
* S3_Implementation of new antibiotic resistance cassettes
* S4_T7RNAP-driven expression from the rDNA spacer
* S5_Analysis of gene expression strength

## Assays

The [Assays] folder contains the results of the individual experiments. The raw and processed data are stored in the `dataset` folder of the assay and the corresponding protocols are in the `protocol` folder. 

### Chapter 1: Identification of potentially silent loci
* S1_1_rDNA spacers on different chromosomes // **Fig. 1**

### Chapter 2: Heterologous expression of the T7RNAP
* S2_1_Genomic map of Adea319 // **Fig. 2A**
* S2_2_Verification of genomic integration by PCR // **Fig. 2B**
* S2_3_Verification of T7RNAP production by Western Blot // **Fig. 2C**

### Chapter 3: Implementation of new antibiotic resistance cassettes
* S3_1_Growth curve of WT and Adea373 on blast // **Fig. 3A**
* S3_2_Growth curve of WT and Adea384 on nours // **Fig. 3B**

### Chapter 4: T7RNAP-driven expression from the rDNA spacer
* S4_1_Genomic map of Adea400 // **Fig. 4A**
* S4_2_Verification of insertion by PCR I // **Fig. 4B**
* S4_3_Verification of insertion by PCR II // **Fig. 4C**
* S4_4_Verification of insertion by Southern Blot // **Fig. 4D**
* S4_5_Growth curves of Adea319 and Adea400 // **Fig. 4E**
* S4_6_Knock-out strategy for T7RNAP // **Fig. 4F**
* S4_7_Verification of knock-out by PCR // **Fig. 4G**
* S4_5_Growth curves of WT, Adea373 and Adea442 // **Fig. 4H**

### Chapter 5: Analysis of gene expression strength
* S5_1_Genomic map of Adea456 // **Fig. 5A**
* S5_2_Verification of insertion by Southern Blot // **Fig. 5B**
* S5_3_Growth curves of WT and Adea456 // **Fig. 5C**
* S5_4_Epifluorescence microscopy of Adea126 and Adea456 // **Fig. 5D**
* S5_5_Quantification of fluorescent cells // **Fig. 5E**
* S5_6_In gel fluorescence assay of Adea126 and Adea456 // **Fig. 5F (top)**
>>>>>>> 90829c7 (Created my first ARC and added data)
* S5_7_Quantification of in gel assay // **Fig. 5F (bottom)**